@@ -4,7 +4,7 @@
 #' `wiki_onthisday()` generates 'on this day' facts from the Wikipedia main page on a specified date.
 #'
 #' @param n_facts An integer determining the number of facts that will be generated, up to a limit of the maximum facts for the date specified.
-#' @param date A date string of the form YYYY-MM-DD.  Default value is yesterday's date.
+#' @param date A date string of the form YYYY-MM-DD.  Default value is a random date since 1 January 2015.
 #' @param bare_fact Logical.  Determining whether the fact should be quoted as is or surrounded by a preamble and courtesy statement.
 #'
 #' @return A vector of strings with random 'on this day' facts from Wikipedia's main page if it exists for the date specified - otherwise "I got nothin'"
@@ -12,7 +12,15 @@
 #' @examples
 #' wiki_onthisday(date = '2020-05-02')
 
-wiki_onthisday <- function(n_facts = 1L, date = Sys.Date() - 1, bare_fact = FALSE) {
+wiki_onthisday <- function(n_facts = 1L, date = sample(seq(as.Date("2015-01-01"), Sys.Date() - 1, by = "day"), 1), bare_fact = FALSE) {
+
+  locale <- Sys.getlocale("LC_TIME")
+
+  if (.Platform$OS.type == "windows") {
+    invisible(Sys.setlocale("LC_TIME", "English"))
+  } else {
+    invisible(Sys.setlocale("LC_TIME", "en_US.UTF-8"))
+  }
 
   # get url from input and read html
   date <- as.Date(date)
@@ -20,6 +28,8 @@ wiki_onthisday <- function(n_facts = 1L, date = Sys.Date() - 1, bare_fact = FALS
   date2 <- gsub("^0+", "", format(date, "%d"))
   date_str <- paste0(date1, date2)
 
+  invisible(Sys.setlocale("LC_TIME", locale))
+
   input <- paste0("https://en.wikipedia.org/wiki/Wikipedia:Main_Page_history/", date_str)
 
   tryCatch({
